@@ -1,33 +1,28 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
-''' Provide wildcard properties.
+""" Provide wildcard properties.
 
 The Any and AnyRef properties can be used to hold values without performing
 any validation.
 
-'''
+"""
 
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import annotations
 
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-
-# External imports
-
 # Bokeh imports
 from .bases import Property
 
@@ -45,7 +40,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 class Any(Property):
-    ''' Accept all values.
+    """ Accept all values.
 
     The ``Any`` property does not do any validation or transformation.
 
@@ -87,13 +82,16 @@ class Any(Property):
 
             >>> m.prop = [1, 2, 3]
 
-    '''
+    """
 
-class AnyRef(Property):
-    ''' Accept all values and force reference discovery. '''
+    def __init__(self, default=None, help=None, serialized=None, readonly=False) -> None:
+        super().__init__(default=default, help=help, serialized=serialized, readonly=readonly)
+
+class AnyRef(Any):
+    """ Accept all values and force reference discovery. """
 
     @property
-    def has_ref(self):
+    def has_ref(self) -> bool:
         return True
 
 #-----------------------------------------------------------------------------
