@@ -1,20 +1,19 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
-'''
+"""
 
-'''
+"""
 
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import annotations
 
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -23,14 +22,10 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 from copy import copy
-import re
-
-# External imports
 
 # Bokeh imports
-from .descriptor_factory import PropertyDescriptorFactory
-from .descriptors import BasicPropertyDescriptor
 from ..has_props import HasProps
+from .descriptor_factory import PropertyDescriptorFactory
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -45,41 +40,28 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 class Include(PropertyDescriptorFactory):
-    ''' Include "mix-in" property collection in a Bokeh model.
+    """ Include "mix-in" property collection in a Bokeh model.
 
     See :ref:`bokeh.core.property_mixins` for more details.
 
-    '''
+    """
 
-    def __init__(self, delegate, help="", use_prefix=True):
+    def __init__(self, delegate, help="", prefix=None) -> None:
         if not (isinstance(delegate, type) and issubclass(delegate, HasProps)):
-            raise ValueError("expected a subclass of HasProps, got %r" % delegate)
+            raise ValueError(f"expected a subclass of HasProps, got {delegate!r}")
 
         self.delegate = delegate
         self.help = help
-        self.use_prefix = use_prefix
+        self.prefix = prefix + "_" if prefix else ""
 
-    def make_descriptors(self, base_name):
+    def make_descriptors(self, _base_name):
         descriptors = []
-        delegate = self.delegate
-        if self.use_prefix:
-            prefix = re.sub("_props$", "", base_name) + "_"
-        else:
-            prefix = ""
 
-        # it would be better if we kept the original generators from
-        # the delegate and built our Include props from those, perhaps.
-        for subpropname in delegate.properties(with_bases=False):
-            fullpropname = prefix + subpropname
-            subprop_descriptor = delegate.lookup(subpropname)
-            if isinstance(subprop_descriptor, BasicPropertyDescriptor):
-                prop = copy(subprop_descriptor.property)
-                if "%s" in self.help:
-                    doc = self.help % subpropname.replace('_', ' ')
-                else:
-                    doc = self.help
-                prop.__doc__ = doc
-                descriptors += prop.make_descriptors(fullpropname)
+        for prop_name in self.delegate.properties():
+            prop_descriptor = self.delegate.lookup(prop_name)
+            prop = copy(prop_descriptor.property)
+            prop.__doc__ = self.help.format(prop=prop_name.replace('_', ' '))
+            descriptors += prop.make_descriptors(self.prefix + prop_name)
 
         return descriptors
 
