@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -12,6 +12,8 @@ components in ``bokeh.server``.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 log = logging.getLogger(__name__)
 
@@ -19,6 +21,17 @@ log = logging.getLogger(__name__)
 # Imports
 #-----------------------------------------------------------------------------
 
+# Standard library imports
+from typing import (
+    TYPE_CHECKING,
+    List,
+    Sequence,
+    Tuple,
+)
+
+if TYPE_CHECKING:
+    from socket import socket
+
 # External imports
 from tornado import netutil
 
@@ -28,8 +41,8 @@ from tornado import netutil
 
 __all__ = (
     'bind_sockets',
-    'check_whitelist',
-    'create_hosts_whitelist',
+    'check_allowlist',
+    'create_hosts_allowlist',
     'match_host',
 )
 
@@ -37,7 +50,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-def bind_sockets(address, port):
+def bind_sockets(address: str | None, port: int) -> Tuple[List[socket], int]:
     ''' Bind a socket to a port on an address.
 
     Args:
@@ -66,48 +79,48 @@ def bind_sockets(address, port):
         assert actual_port == port
     return ss, actual_port
 
-def check_whitelist(host, whitelist):
-    ''' Check a given request host against a whitelist.
+def check_allowlist(host: str, allowlist: Sequence[str]) -> bool:
+    ''' Check a given request host against a allowlist.
 
     Args:
         host (str) :
-            A host string to compare against a whitelist.
+            A host string to compare against a allowlist.
 
             If the host does not specify a port, then ``":80"`` is implicitly
             assumed.
 
-        whitelist (seq[str]) :
+        allowlist (seq[str]) :
             A list of host patterns to match against
 
     Returns:
-        ``True``, if ``host`` matches any pattern in ``whitelist``, otherwise
+        ``True``, if ``host`` matches any pattern in ``allowlist``, otherwise
         ``False``
 
      '''
     if ':' not in host:
         host = host + ':80'
 
-    if host in whitelist:
+    if host in allowlist:
         return True
 
-    return any(match_host(host, pattern) for pattern in whitelist)
+    return any(match_host(host, pattern) for pattern in allowlist)
 
-def create_hosts_whitelist(host_list, port):
+def create_hosts_allowlist(host_list: Sequence[str] | None, port: int) -> List[str]:
     '''
 
-    This whitelist can be used to restrict websocket or other connections to
+    This allowlist can be used to restrict websocket or other connections to
     only those explicitly originating from approved hosts.
 
     Args:
         host_list (seq[str]) :
             A list of string `<name>` or `<name>:<port>` values to add to the
-            whitelist.
+            allowlist.
 
             If no port is specified in a host string, then ``":80"``  is
             implicitly assumed.
 
         port (int) :
-            If ``host_list`` is empty or ``None``, then the whitelist will
+            If ``host_list`` is empty or ``None``, then the allowlist will
             be the single item list `` [ 'localhost:<port>' ]``
 
             If ``host_list`` is not empty, this parameter has no effect.
@@ -126,7 +139,7 @@ def create_hosts_whitelist(host_list, port):
     if not host_list:
         return ['localhost:' + str(port)]
 
-    hosts = []
+    hosts: List[str] = []
     for host in host_list:
         if '*' in host:
             log.warning(
@@ -155,7 +168,7 @@ def create_hosts_whitelist(host_list, port):
             raise ValueError("Invalid host value: %s" % host)
     return hosts
 
-def match_host(host, pattern):
+def match_host(host: str, pattern: str) -> bool:
     ''' Match a host string against a pattern
 
     Args:
@@ -205,28 +218,26 @@ def match_host(host, pattern):
         False
 
     '''
+    host_port: str | None = None
     if ':' in host:
         host, host_port = host.rsplit(':', 1)
-    else:
-        host_port = None
 
+    pattern_port: str | None = None
     if ':' in pattern:
         pattern, pattern_port = pattern.rsplit(':', 1)
         if pattern_port == '*':
             pattern_port = None
-    else:
-        pattern_port = None
 
     if pattern_port is not None and host_port != pattern_port:
         return False
 
-    host = host.split('.')
-    pattern = pattern.split('.')
+    host_parts = host.split('.')
+    pattern_parts = pattern.split('.')
 
-    if len(pattern) > len(host):
+    if len(pattern_parts) > len(host_parts):
         return False
 
-    for h, p in zip(host, pattern):
+    for h, p in zip(host_parts, pattern_parts):
         if h == p or p == '*':
             continue
         else:
