@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -12,6 +12,8 @@ or (if only one) redirects to the route of that applications.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 log = logging.getLogger(__name__)
 
@@ -63,6 +65,12 @@ class RootHandler(AuthMixin, RequestHandler):
             index = "app_index.html" if self.index is None else self.index
             self.render(index, prefix=prefix, items=sorted(self.applications.keys()))
 
+    # NOTE: The methods below exist on both AuthMixin and RequestHandler. This
+    # makes it explicit which of the versions is intended to be called.
+    get_login_url = AuthMixin.get_login_url
+    get_current_user = AuthMixin.get_current_user
+    prepare = AuthMixin.prepare
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
