@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -10,11 +10,12 @@ get_provider
     Use this function to retrieve an instance of a predefined tile provider.
 
     Args:
-        provider_name (Union[str, Vendors])
+        provider_name (Union[str, Vendors, xyzservices.TileProvider])
             Name of the tile provider to supply.
 
             Use a ``tile_providers.Vendors`` enumeration value, or the string
-            name of one of the known providers.
+            name of one of the known providers. Use
+            :class:`xyzservices.TileProvider` to pass custom tile providers.
 
     Returns:
         WMTSTileProviderSource: The desired tile provider instance
@@ -32,6 +33,10 @@ get_provider
                 >>> get_provider('CARTODBPOSITRON')
                 <class 'bokeh.models.tiles.WMTSTileSource'>
 
+                >>> import xyzservices.providers as xyz
+                >>> get_provider(xyz.CartoDB.Positron)
+                <class 'bokeh.models.tiles.WMTSTileSource'>
+
 The available built-in tile providers are listed in the ``Vendors`` enum:
 
 .. bokeh-enum:: Vendors
@@ -43,80 +48,93 @@ to obtain a tile provider to use with a Bokeh plot. Representative samples of
 each tile provider are shown below.
 
 CARTODBPOSITRON
-    Tile Source for CartoDB Tile Service
+---------------
 
-    .. raw:: html
+Tile Source for CartoDB Tile Service
 
-        <img src="https://tiles.basemaps.cartocdn.com/light_all/14/2627/6331.png" />
+.. raw:: html
+
+    <img src="https://tiles.basemaps.cartocdn.com/light_all/14/2627/6331.png" />
 
 CARTODBPOSITRON_RETINA
-    Tile Source for CartoDB Tile Service (tiles at 'retina' resolution)
+----------------------
 
-    .. raw:: html
+Tile Source for CartoDB Tile Service (tiles at 'retina' resolution)
 
-        <img src="https://tiles.basemaps.cartocdn.com/light_all/14/2627/6331@2x.png" />
+.. raw:: html
+
+    <img src="https://tiles.basemaps.cartocdn.com/light_all/14/2627/6331@2x.png" />
 
 ESRI_IMAGERY
-    Tile Source for ESRI public tiles.
+------------
 
-    .. raw:: html
+Tile Source for ESRI public tiles.
 
-        <img src="https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/14/6331/2627.jpg" />
+.. raw:: html
+
+    <img src="https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/14/6331/2627.jpg" />
 
 OSM
-    Tile Source for Open Street Maps.
+---
 
-    .. raw:: html
+Tile Source for Open Street Maps.
 
-        <img src="https://c.tile.openstreetmap.org/14/2627/6331.png" />
+.. raw:: html
+
+    <img src="https://c.tile.openstreetmap.org/14/2627/6331.png" />
 
 STAMEN_TERRAIN
-    Tile Source for Stamen Terrain Service
+--------------
 
-    .. raw:: html
+Tile Source for Stamen Terrain Service
 
-        <img src="http://c.tile.stamen.com/terrain/14/2627/6331.png" />
+.. raw:: html
+
+    <img src="https://stamen-tiles.a.ssl.fastly.net/terrain/14/2627/6331.png" />
 
 STAMEN_TERRAIN_RETINA
-    Tile Source for Stamen Terrain Service (tiles at 'retina' resolution)
+---------------------
 
-    .. raw:: html
+Tile Source for Stamen Terrain Service (tiles at 'retina' resolution)
 
-        <img src="http://c.tile.stamen.com/terrain/14/2627/6331@2x.png" />
+.. raw:: html
+
+    <img src="https://stamen-tiles.a.ssl.fastly.net/terrain/14/2627/6331@2x.png" />
 
 STAMEN_TONER
-    Tile Source for Stamen Toner Service
+------------
 
-    .. raw:: html
+Tile Source for Stamen Toner Service
 
-        <img src="http://c.tile.stamen.com/toner/14/2627/6331.png" />
+.. raw:: html
+
+    <img src="https://stamen-tiles.a.ssl.fastly.net/toner/14/2627/6331.png" />
 
 STAMEN_TONER_BACKGROUND
-    Tile Source for Stamen Toner Background Service which does not include labels
+-----------------------
 
-    .. raw:: html
+Tile Source for Stamen Toner Background Service which does not include labels
 
-        <img src="http://c.tile.stamen.com/toner-background/14/2627/6331.png" />
+.. raw:: html
+
+    <img src="https://stamen-tiles.a.ssl.fastly.net/toner-background/14/2627/6331.png" />
 
 STAMEN_TONER_LABELS
-    Tile Source for Stamen Toner Service which includes only labels
+-------------------
 
-    .. raw:: html
+Tile Source for Stamen Toner Service which includes only labels
 
-        <img src="http://c.tile.stamen.com/toner-labels/14/2627/6331.png" />
+.. raw:: html
 
-WIKIMEDIA
-    Tile Source for Wikimedia tile service.
-
-    .. raw:: html
-
-        <img src="https://maps.wikimedia.org/osm-intl/14/2627/6331@2x.png" />
+    <img src="https://stamen-tiles.a.ssl.fastly.net/toner-labels/14/2627/6331.png" />
 
 '''
 
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 
 log = logging.getLogger(__name__)
@@ -132,11 +150,15 @@ import types
 # Bokeh imports
 from bokeh.core.enums import enumeration
 
+# Bokeh imports
+from .util.dependencies import import_optional
+
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
 
 # __all__ defined at the bottom on the class module
+xyzservices = import_optional('xyzservices')
 
 #-----------------------------------------------------------------------------
 # General API
@@ -210,6 +232,14 @@ class _TileProvidersModule(types.ModuleType):
             # This allows `get_provider(CARTODBPOSITRON)` to work
             return WMTSTileSource(url=provider_name.url, attribution=provider_name.attribution)
 
+        if xyzservices and isinstance(provider_name, xyzservices.TileProvider):
+            return WMTSTileSource(
+                url=provider_name.build_url(scale_factor="@2x"),
+                attribution=provider_name.html_attribution,
+                min_zoom=provider_name.get("min_zoom", 0),
+                max_zoom=provider_name.get("max_zoom", 30),
+            )
+
         selected_provider = provider_name.upper()
 
         if selected_provider not in self.Vendors:
@@ -248,7 +278,7 @@ class _TileProvidersModule(types.ModuleType):
 # Code
 #-----------------------------------------------------------------------------
 
-_mod = _TileProvidersModule(str('bokeh.tile_providers'))
+_mod = _TileProvidersModule("bokeh.tile_providers")
 _mod.__doc__ = __doc__
 _mod.__all__ = (
     'CARTODBPOSITRON',
