@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -28,7 +30,7 @@ import bokeh.application.handlers.document_lifecycle as bahd # isort:skip
 #-----------------------------------------------------------------------------
 
 class MockSessionContext:
-    def __init__(self, doc):
+    def __init__(self, doc: Document) -> None:
         self._document = doc
         self.status = None
         self.counter = 0
@@ -71,7 +73,7 @@ class Test_DocumentLifecycleHandler:
         session_context = MockSessionContext(doc)
         await handler.on_session_destroyed(session_context)
         assert session_context.status == 'Destroyed'
-        assert session_context._document.session_destroyed_callbacks == set()
+        assert set(session_context._document.session_destroyed_callbacks) == set()
 
     async def test_document_on_session_destroyed_calls_multiple(self) -> None:
         doc = Document()
@@ -91,7 +93,7 @@ class Test_DocumentLifecycleHandler:
         await handler.on_session_destroyed(session_context)
         assert session_context.counter == 3, 'DocumentLifecycleHandler did not call all callbacks'
 
-    async def test_document_on_session_destroyed_exceptions(self, caplog) -> None:
+    async def test_document_on_session_destroyed_exceptions(self, caplog: pytest.LogCaptureFixture) -> None:
         doc = Document()
 
         def blowup(session_context):
