@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -18,11 +20,11 @@ import pytest ; pytest
 import logging
 
 # External imports
-import mock
+from mock import MagicMock, patch
 
 # Bokeh imports
 from bokeh.application.handlers import CodeHandler, FunctionHandler, Handler
-from bokeh.core.properties import Instance, Int
+from bokeh.core.properties import Instance, Int, Nullable
 from bokeh.document import Document
 from bokeh.model import Model
 from bokeh.plotting import figure
@@ -43,12 +45,12 @@ class AnotherModelInTestApplication(Model):
 
 class SomeModelInTestApplication(Model):
     foo = Int(2)
-    child = Instance(Model)
+    child = Nullable(Instance(Model))
 
 class RequestHandler(Handler):
     _failed = False
     _static = None
-    def __init__(self, data):
+    def __init__(self, data) -> None:
         self._data = data
 
     def process_request(self, request):
@@ -58,8 +60,8 @@ class RequestHandler(Handler):
 # General API
 #-----------------------------------------------------------------------------
 
-class Test_Application(object):
 
+class Test_Application:
     # Public methods ----------------------------------------------------------
 
     def test_empty(self) -> None:
@@ -132,7 +134,7 @@ class Test_Application(object):
         a.create_document()
         assert a.metadata == "foo"
 
-    def test_failed_handler(self, caplog) -> None:
+    def test_failed_handler(self, caplog: pytest.LogCaptureFixture) -> None:
         a = baa.Application()
         handler = CodeHandler(filename="junk", source="bad(")
         a.add(handler)
@@ -185,16 +187,16 @@ class Test_Application(object):
             a.add(handler2)
         assert "More than one static path" in str(e.value)
 
-    @mock.patch('bokeh.document.document.check_integrity')
-    def test_application_validates_document_by_default(self, check_integrity) -> None:
+    @patch('bokeh.document.document.check_integrity')
+    def test_application_validates_document_by_default(self, check_integrity: MagicMock) -> None:
         a = baa.Application()
         d = Document()
         d.add_root(figure())
         a.initialize_document(d)
         assert check_integrity.called
 
-    @mock.patch('bokeh.document.document.check_integrity')
-    def test_application_doesnt_validate_document_due_to_env_var(self, check_integrity, monkeypatch) -> None:
+    @patch('bokeh.document.document.check_integrity')
+    def test_application_doesnt_validate_document_due_to_env_var(self, check_integrity: MagicMock, monkeypatch: pytest.MonkeyPatch) -> None:
         monkeypatch.setenv("BOKEH_VALIDATE_DOC", "false")
         a = baa.Application()
         d = Document()
@@ -206,16 +208,16 @@ class Test_Application(object):
 # Dev API
 #-----------------------------------------------------------------------------
 
-class Test_ServerContext(object):
 
+class Test_ServerContext:
     # Public methods ----------------------------------------------------------
 
     def test_abstract(self) -> None:
         with pytest.raises(TypeError):
             baa.ServerContext()
 
-class Test_SessionContext(object):
 
+class Test_SessionContext:
     def test_abstract(self) -> None:
         with pytest.raises(TypeError):
             baa.SessionContext()
