@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -18,7 +20,9 @@ import pytest ; pytest
 from os.path import join
 
 # Bokeh imports
+from bokeh._testing.util.types import Capture
 from bokeh.command.bootstrap import main
+from bokeh.command.subcommand import Argument
 
 # Module under test
 import bokeh.command.subcommands.info as scinfo # isort:skip
@@ -37,6 +41,7 @@ import bokeh.command.subcommands.info as scinfo # isort:skip
 
 def test_create() -> None:
     import argparse
+
     from bokeh.command.subcommand import Subcommand
 
     obj = scinfo.Info(parser=argparse.ArgumentParser())
@@ -50,17 +55,17 @@ def test_help() -> None:
 
 def test_args() -> None:
     assert scinfo.Info.args == (
-        ('--static', dict(
+        ('--static', Argument(
             action='store_true',
             help="Print the locations of BokehJS static files",
         )),
     )
 
-def test_run(capsys) -> None:
+def test_run(capsys: Capture) -> None:
     main(["bokeh", "info"])
     out, err = capsys.readouterr()
     lines = out.split("\n")
-    assert len(lines) == 8
+    assert len(lines) == 9
     assert lines[0].startswith("Python version")
     assert lines[1].startswith("IPython version")
     assert lines[2].startswith("Tornado version")
@@ -68,10 +73,11 @@ def test_run(capsys) -> None:
     assert lines[4].startswith("BokehJS static")
     assert lines[5].startswith("node.js version")
     assert lines[6].startswith("npm version")
-    assert lines[7] == ""
+    assert lines[7].startswith("Operating system")
+    assert lines[8] == ""
     assert err == ""
 
-def test_run_static(capsys) -> None:
+def test_run_static(capsys: Capture) -> None:
     main(["bokeh", "info", "--static"])
     out, err = capsys.readouterr()
     assert err == ""
