@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -19,12 +21,10 @@ import os
 import tempfile
 
 # External imports
-from mock import patch
+from mock import MagicMock, patch
 
 # Bokeh imports
-from bokeh.document import Document
-from bokeh.layouts import row
-from bokeh.plotting import figure
+from bokeh._testing.util.types import Capture
 
 # Module under test
 import bokeh.command.util as util # isort:skip
@@ -41,7 +41,7 @@ import bokeh.command.util as util # isort:skip
 # Dev API
 #-----------------------------------------------------------------------------
 
-def test_die(capsys) -> None:
+def test_die(capsys: Capture) -> None:
     with pytest.raises(SystemExit):
         util.die("foo")
     out, err = capsys.readouterr()
@@ -70,7 +70,7 @@ If this is not the case, renaming main.py will suppress this warning.
 """
 
 @patch('warnings.warn')
-def test_build_single_handler_application_main_py(mock_warn) -> None:
+def test_build_single_handler_application_main_py(mock_warn: MagicMock) -> None:
     f = tempfile.NamedTemporaryFile(suffix="main.py", delete=False)
     f.close() #close file to open it later on windows
     util.build_single_handler_application(f.name)
@@ -78,61 +78,6 @@ def test_build_single_handler_application_main_py(mock_warn) -> None:
     assert mock_warn.call_args[0] == (DIRSTYLE_MAIN_WARNING_COPY,)
     os.remove(f.name)
 
-_SIZE_WARNING = "Width/height arguments will be ignored for this muliple layout. (Size valus only apply when exporting single plots.)"
-
-class Test_set_single_plot_width_height:
-    def test_neither(self) -> None:
-        p = figure(plot_width=200, plot_height=300)
-        d = Document()
-        d.add_root(p)
-        util.set_single_plot_width_height(d, None, None)
-        assert p.plot_width == 200
-        assert p.plot_height == 300
-
-    def test_width(self) -> None:
-        p = figure(plot_width=200, plot_height=300)
-        d = Document()
-        d.add_root(p)
-        util.set_single_plot_width_height(d, 400, None)
-        assert p.plot_width == 400
-        assert p.plot_height == 300
-
-    def test_height(self) -> None:
-        p = figure(plot_width=200, plot_height=300)
-        d = Document()
-        d.add_root(p)
-        util.set_single_plot_width_height(d, None, 400)
-        assert p.plot_width == 200
-        assert p.plot_height == 400
-
-    def test_both(self) -> None:
-        p = figure(plot_width=200, plot_height=300)
-        d = Document()
-        d.add_root(p)
-        util.set_single_plot_width_height(d, 400, 500)
-        assert p.plot_width == 400
-        assert p.plot_height == 500
-
-    def test_multiple_roots(self) -> None:
-        p1 = figure(plot_width=200, plot_height=300)
-        p2 = figure(plot_width=200, plot_height=300)
-        d = Document()
-        d.add_root(p1)
-        d.add_root(p2)
-        with pytest.warns(UserWarning) as warns:
-            util.set_single_plot_width_height(d, 400, 500)
-            assert len(warns) == 1
-            assert warns[0].message.args[0] == _SIZE_WARNING
-
-    def test_layout(self) -> None:
-        p = figure(plot_width=200, plot_height=300)
-        d = Document()
-        d.add_root(row(p))
-        with pytest.warns(UserWarning) as warns:
-            util.set_single_plot_width_height(d, 400, 500)
-            assert len(warns) == 1
-            assert warns[0].message.args[0] == _SIZE_WARNING
-
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
