@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,9 +17,10 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
-from _util_property import _TestHasProps, _TestModel
 from bokeh._testing.util.api import verify_all
 
+from _util_property import _TestHasProps, _TestModel
+
 # Module under test
 import bokeh.core.property.any as bcpa # isort:skip
 
@@ -34,8 +37,8 @@ ALL = (
 # General API
 #-----------------------------------------------------------------------------
 
-class Test_Any(object):
 
+class Test_Any:
     def test_valid(self) -> None:
         prop = bcpa.Any()
         assert prop.is_valid(None)
@@ -60,8 +63,8 @@ class Test_Any(object):
         prop = bcpa.Any()
         assert not prop.has_ref
 
-class Test_AnyRef(object):
 
+class Test_AnyRef:
     def test_valid(self) -> None:
         prop = bcpa.AnyRef()
         assert prop.is_valid(None)
