@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -16,10 +18,11 @@ import pytest ; pytest
 
 # External imports
 import numpy as np
-from mock import patch
+from mock import MagicMock, patch
 
 # Bokeh imports
 from bokeh._testing.util.api import verify_all
+from bokeh._testing.util.types import Capture
 from bokeh.core.has_props import HasProps
 
 # Module under test
@@ -41,10 +44,9 @@ ALL = (
 # General API
 #-----------------------------------------------------------------------------
 
-
 class TestProperty:
     @patch('bokeh.core.property.bases.Property.validate')
-    def test_is_valid_supresses_validation_detail(self, mock_validate) -> None:
+    def test_is_valid_supresses_validation_detail(self, mock_validate: MagicMock) -> None:
         p = bcpb.Property()
         p.is_valid(None)
         assert mock_validate.called
@@ -105,7 +107,7 @@ class TestProperty:
                 p.prepare_value(hp, "foo", 10)
                 assert str(e) == "bad True name, 10"
 
-    def test_matches_basic_types(self, capsys) -> None:
+    def test_matches_basic_types(self, capsys: Capture) -> None:
         p = bcpb.Property()
         for x in [1, 1.2, "a", np.arange(4), None, False, True, {}, []]:
                 assert p.matches(x, x) is True
@@ -113,7 +115,7 @@ class TestProperty:
         out, err = capsys.readouterr()
         assert err == ""
 
-    def test_matches_compatible_arrays(self, capsys) -> None:
+    def test_matches_compatible_arrays(self, capsys: Capture) -> None:
         p = bcpb.Property()
         a = np.arange(5)
         b = np.arange(5)
@@ -125,7 +127,7 @@ class TestProperty:
         out, err = capsys.readouterr()
         assert err == ""
 
-    def test_matches_incompatible_arrays(self, capsys) -> None:
+    def test_matches_incompatible_arrays(self, capsys: Capture) -> None:
         p = bcpb.Property()
         a = np.arange(5)
         b = np.arange(5).astype(str)
@@ -134,7 +136,7 @@ class TestProperty:
         # no way to suppress FutureWarning in this case
         # assert err == ""
 
-    def test_matches_dicts_with_array_values(self, capsys) -> None:
+    def test_matches_dicts_with_array_values(self, capsys: Capture) -> None:
         p = bcpb.Property()
         d1 = dict(foo=np.arange(10))
         d2 = dict(foo=np.arange(10))
@@ -151,7 +153,7 @@ class TestProperty:
         out, err = capsys.readouterr()
         assert err == ""
 
-    def test_matches_non_dict_containers_with_array_false(self, capsys) -> None:
+    def test_matches_non_dict_containers_with_array_false(self, capsys: Capture) -> None:
         p = bcpb.Property()
         d1 = [np.arange(10)]
         d2 = [np.arange(10)]
@@ -166,7 +168,7 @@ class TestProperty:
         out, err = capsys.readouterr()
         assert err == ""
 
-    def test_matches_dicts_with_series_values(self, capsys, pd) -> None:
+    def test_matches_dicts_with_series_values(self, capsys: Capture, pd) -> None:
         p = bcpb.Property()
         d1 = pd.DataFrame(dict(foo=np.arange(10)))
         d2 = pd.DataFrame(dict(foo=np.arange(10)))
@@ -183,7 +185,7 @@ class TestProperty:
         out, err = capsys.readouterr()
         assert err == ""
 
-    def test_matches_dicts_with_index_values(self, capsys, pd) -> None:
+    def test_matches_dicts_with_index_values(self, capsys: Capture, pd) -> None:
         p = bcpb.Property()
         d1 = pd.DataFrame(dict(foo=np.arange(10)))
         d2 = pd.DataFrame(dict(foo=np.arange(10)))
@@ -210,6 +212,19 @@ class TestProperty:
         bcpb.Property._should_validate = True
         assert bcpb.validation_on()
 
+    def test__hinted_value_is_identity(self) -> None:
+        p = bcpb.Property()
+        assert p._hinted_value(10, "hint") == 10
+        assert p._hinted_value(10, None) == 10
+
+    @patch('bokeh.core.property.bases.Property._hinted_value')
+    def test_prepare_value_uses__hinted_value(self, mock_hv: MagicMock) -> None:
+        hp = HasProps()
+        p = bcpb.Property()
+
+        p.prepare_value(hp, "foo", 10)
+        assert mock_hv.called
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
