@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,10 +17,11 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
-from _util_property import _TestHasProps, _TestModel
 from bokeh._testing.util.api import verify_all
 from bokeh.core.properties import Float, Int
 
+from _util_property import _TestHasProps, _TestModel
+
 # Module under test
 import bokeh.core.property.numeric as bcpn # isort:skip
 
@@ -40,13 +43,11 @@ ALL = (
 # General API
 #-----------------------------------------------------------------------------
 
-class Test_Angle(object):
 
+class Test_Angle:
     def test_valid(self) -> None:
         prop = bcpn.Angle()
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(False)
         assert prop.is_valid(True)
@@ -59,6 +60,7 @@ class Test_Angle(object):
     def test_invalid(self) -> None:
         prop = bcpn.Angle()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(1.0+1.0j)
         assert not prop.is_valid("")
         assert not prop.is_valid(())
@@ -75,8 +77,8 @@ class Test_Angle(object):
         prop = bcpn.Angle()
         assert str(prop) == "Angle"
 
-class Test_Interval(object):
 
+class Test_Interval:
     def test_init(self) -> None:
         with pytest.raises(TypeError):
             bcpn.Interval()
@@ -87,8 +89,6 @@ class Test_Interval(object):
     def test_valid_int(self) -> None:
         prop = bcpn.Interval(Int, 0, 255)
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(False)
         assert prop.is_valid(True)
@@ -100,6 +100,7 @@ class Test_Interval(object):
     def test_invalid_int(self) -> None:
         prop = bcpn.Interval(Int, 0, 255)
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(0.0)
         assert not prop.is_valid(1.0)
         assert not prop.is_valid(1.0+1.0j)
@@ -116,8 +117,6 @@ class Test_Interval(object):
     def test_valid_float(self) -> None:
         prop = bcpn.Interval(Float, 0.0, 1.0)
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(False)
         assert prop.is_valid(True)
@@ -131,6 +130,7 @@ class Test_Interval(object):
     def test_invalid_float(self) -> None:
         prop = bcpn.Interval(Float, 0.0, 1.0)
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(1.0+1.0j)
         assert not prop.is_valid("")
         assert not prop.is_valid(())
@@ -150,13 +150,11 @@ class Test_Interval(object):
         prop = bcpn.Interval(Float, 0.0, 1.0)
         assert str(prop) == "Interval(Float, 0.0, 1.0)"
 
-class Test_Size(object):
 
+class Test_Size:
     def test_valid(self) -> None:
         prop = bcpn.Size()
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(False)
         assert prop.is_valid(True)
@@ -171,6 +169,7 @@ class Test_Size(object):
     def test_invalid(self) -> None:
         prop = bcpn.Size()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(1.0+1.0j)
         assert not prop.is_valid("")
         assert not prop.is_valid(())
@@ -190,13 +189,11 @@ class Test_Size(object):
         prop = bcpn.Size()
         assert str(prop) == "Size"
 
-class Test_Percent(object):
 
+class Test_Percent:
     def test_valid(self) -> None:
         prop = bcpn.Percent()
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(False)
         assert prop.is_valid(True)
@@ -210,6 +207,7 @@ class Test_Percent(object):
     def test_invalid(self) -> None:
         prop = bcpn.Percent()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(1.0+1.0j)
         assert not prop.is_valid("")
         assert not prop.is_valid(())
@@ -229,13 +227,11 @@ class Test_Percent(object):
         prop = bcpn.Percent()
         assert str(prop) == "Percent"
 
-class Test_NonNegativeInt(object):
 
+class Test_NonNegativeInt:
     def test_valid(self) -> None:
         prop = bcpn.NonNegativeInt()
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(False)
         assert prop.is_valid(True)
@@ -248,6 +244,7 @@ class Test_NonNegativeInt(object):
     def test_invalid(self) -> None:
         prop = bcpn.NonNegativeInt()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(-1)
         assert not prop.is_valid(0.0)
         assert not prop.is_valid(1.0)
@@ -270,13 +267,11 @@ class Test_NonNegativeInt(object):
         prop = bcpn.NonNegativeInt()
         assert str(prop) == "NonNegativeInt"
 
-class Test_PositiveInt(object):
 
+class Test_PositiveInt:
     def test_valid(self) -> None:
         prop = bcpn.PositiveInt()
 
-        assert prop.is_valid(None)
-
         # TODO (bev) should fail
         assert prop.is_valid(True)
 
@@ -287,8 +282,8 @@ class Test_PositiveInt(object):
     def test_invalid(self) -> None:
         prop = bcpn.PositiveInt()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(False)
-
         assert not prop.is_valid(-1)
         assert not prop.is_valid(0)
         assert not prop.is_valid(0.0)
