@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,9 +17,10 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
-from _util_property import _TestHasProps, _TestModel
 from bokeh._testing.util.api import verify_all
 
+from _util_property import _TestHasProps, _TestModel
+
 # Module under test
 import bokeh.core.property.string as bcpr # isort:skip
 
@@ -27,6 +30,7 @@ import bokeh.core.property.string as bcpr # isort:skip
 
 ALL = (
     'Regex',
+    'MathString',
     'Base64String',
 )
 
@@ -34,8 +38,8 @@ ALL = (
 # General API
 #-----------------------------------------------------------------------------
 
-class Test_Regex(object):
 
+class Test_Regex:
     def test_init(self) -> None:
         with pytest.raises(TypeError):
             bcpr.Regex()
@@ -43,8 +47,6 @@ class Test_Regex(object):
     def test_valid(self) -> None:
         prop = bcpr.Regex("^x*$")
 
-        assert prop.is_valid(None)
-
         assert prop.is_valid("")
         assert prop.is_valid("x")
 
@@ -53,6 +55,7 @@ class Test_Regex(object):
 
         assert not prop.is_valid("xy")
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(False)
         assert not prop.is_valid(True)
         assert not prop.is_valid(0)
