@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,15 +17,22 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # External imports
-from mock import patch
+from mock import MagicMock, patch
 
 # Bokeh imports
-from bokeh.core.properties import Alias, Either, Int, List, Nullable, NumberSpec, Override, String
-from bokeh.core.property.dataspec import field, value
-from bokeh.core.property.descriptors import (
-    BasicPropertyDescriptor,
-    DataSpecPropertyDescriptor,
+from bokeh.core.properties import (
+    Alias,
+    AngleSpec,
+    Either,
+    Int,
+    List,
+    Nullable,
+    NumberSpec,
+    Override,
+    String,
 )
+from bokeh.core.property.dataspec import field, value
+from bokeh.core.property.descriptors import DataSpecPropertyDescriptor, PropertyDescriptor
 from bokeh.core.property.singletons import Intrinsic
 
 # Module under test
@@ -248,12 +257,12 @@ def test_HasProps_update_from_json() -> None:
     assert c.lst2 == [1,2]
 
 @patch('bokeh.core.has_props.HasProps.set_from_json')
-def test_HasProps_update_from_json_passes_models_and_setter(mock_set) -> None:
+def test_HasProps_update_from_json_passes_models_and_setter(mock_set: MagicMock) -> None:
     c = Child()
     c.update_from_json(dict(lst1=[1,2]), models="foo", setter="bar")
     assert mock_set.called
-    assert mock_set.call_args[0] == ('lst1', [1, 2], 'foo', 'bar')
-    assert mock_set.call_args[1] == {}
+    assert mock_set.call_args[0] == ('lst1', [1, 2])
+    assert mock_set.call_args[1] == {'models': 'foo', 'setter': 'bar'}
 
 def test_HasProps_set() -> None:
     c = Child()
@@ -283,13 +292,13 @@ def test_HasProps_set_error() -> None:
 def test_HasProps_lookup() -> None:
     p = Parent()
     d = p.lookup('int1')
-    assert isinstance(d, BasicPropertyDescriptor)
+    assert isinstance(d, PropertyDescriptor)
     assert d.name == 'int1'
     d = p.lookup('ds1')
     assert isinstance(d, DataSpecPropertyDescriptor)
     assert d.name == 'ds1'
     d = p.lookup('lst1')
-    assert isinstance(d, BasicPropertyDescriptor)
+    assert isinstance(d, PropertyDescriptor)
     assert d.name == 'lst1'
 
 def test_HasProps_apply_theme() -> None:
@@ -473,6 +482,17 @@ def test_HasProps_apply_theme_func_default() -> None:
     c.foo = 50
     assert c.foo == 50
 
+def test_has_props_dupe_prop() -> None:
+    try:
+        class DupeProps(hp.HasProps):
+            bar = AngleSpec()
+            bar_units = String()
+    except RuntimeError as e:
+        assert str(e) == "Two property generators both created DupeProps.bar_units"
+    else:
+        assert False
+
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
