@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,25 +8,29 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
+# Standard library imports
+from typing import Any, cast
+
 # External imports
-from mock import patch
+from mock import MagicMock, patch
 
 # Bokeh imports
 from bokeh.core.properties import Int
-from bokeh.core.validation.errors import codes as ec
-from bokeh.core.validation.warnings import codes as wc
+from bokeh.core.validation.check import ValidationIssue, ValidationIssues
+from bokeh.core.validation.issue import Error, Warning
 from bokeh.model import Model
 
 # Module under test
 import bokeh.core.validation as v # isort:skip
 
-
 #-----------------------------------------------------------------------------
 # Setup
 #-----------------------------------------------------------------------------
@@ -40,28 +44,28 @@ import bokeh.core.validation as v # isort:skip
 #-----------------------------------------------------------------------------
 
 def test_error_decorator_code() -> None:
-    for code in ec:
-        @v.error(code)
+    for error in Error.all():
+        @v.error(error)
         def good():
             return None
         assert good() == []
 
-        @v.error(code)
+        @v.error(error)
         def bad():
             return "bad"
-        assert bad() == [(code,) + ec[code] + ('bad',)]
+        assert bad() == [ValidationIssue(error.code, error.name, error.description, "bad")]
 
 def test_warning_decorator_code() -> None:
-    for code in wc:
-        @v.warning(code)
+    for warning in Warning.all():
+        @v.warning(warning)
         def good():
             return None
         assert good() == []
 
-        @v.warning(code)
+        @v.warning(warning)
         def bad():
             return "bad"
-        assert bad() == [(code,) + wc[code] + ('bad',)]
+        assert bad() == [ValidationIssue(warning.code, warning.name, warning.description, "bad")]
 
 def test_error_decorator_custom() -> None:
     @v.error("E1")
@@ -72,7 +76,7 @@ def test_error_decorator_custom() -> None:
     @v.error("E2")
     def bad():
         return "bad"
-    assert bad() == [(9999, 'EXT:E2', 'Custom extension reports error', 'bad')]
+    assert bad() == [ValidationIssue(9999, "EXT:E2", "Custom extension reports error", "bad")]
 
 def test_warning_decorator_custom() -> None:
     @v.warning("W1")
@@ -83,7 +87,7 @@ def test_warning_decorator_custom() -> None:
     @v.warning("W2")
     def bad():
         return "bad"
-    assert bad() == [ (9999, 'EXT:W2', 'Custom extension reports warning', 'bad')]
+    assert bad() == [ValidationIssue(9999, "EXT:W2", "Custom extension reports warning", "bad")]
 
 class Mod(Model):
 
@@ -97,81 +101,109 @@ class Mod(Model):
     def _check_warning(self):
         if self.foo < -5: return "wrn"
 
+def test_check_integrity_pass() -> None:
+    m = Mod()
+    issues = ValidationIssues(error=[], warning=[])
+    assert v.check_integrity([m]) == issues
+
+def test_check_integrity_error() -> None:
+    m = Mod(foo = 10)
+    issues = ValidationIssues(
+        error=[ValidationIssue(9999, "EXT:E", "Custom extension reports error", "err")],
+        warning=[],
+    )
+    assert v.check_integrity([m]) == issues
+
+def test_check_integrity_warning() -> None:
+    m = Mod(foo = -10)
+    issues = ValidationIssues(
+        error=[],
+        warning=[ValidationIssue(9999, "EXT:W", "Custom extension reports warning", "wrn")],
+    )
+    assert v.check_integrity([m]) == issues
+
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_check_pass(mock_warn, mock_error) -> None:
+def test_check_pass(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     m = Mod()
 
-    v.check_integrity([m])
+    issues = v.check_integrity([m])
+    v.process_validation_issues(issues)
     assert not mock_error.called
     assert not mock_warn.called
 
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_check_error(mock_warn, mock_error) -> None:
+def test_check_error(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     m = Mod(foo=10)
-    v.check_integrity([m])
+    issues = v.check_integrity([m])
+    v.process_validation_issues(issues)
     assert mock_error.called
     assert not mock_warn.called
 
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_check_warn(mock_warn, mock_error) -> None:
+def test_check_warn(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     m = Mod(foo=-10)
-    v.check_integrity([m])
+    issues = v.check_integrity([m])
+    v.process_validation_issues(issues)
     assert not mock_error.called
     assert mock_warn.called
 
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_silence_and_check_warn(mock_warn, mock_error) -> None:
+def test_silence_and_check_warn(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     from bokeh.core.validation.warnings import EXT
     m = Mod(foo=-10)
     try:
         v.silence(EXT)  # turn the warning off
-        v.check_integrity([m])
+        issues = v.check_integrity([m])
+        v.process_validation_issues(issues)
         assert not mock_error.called
         assert not mock_warn.called
     finally:
         v.silence(EXT, False)  # turn the warning back on
-        v.check_integrity([m])
+        issues = v.check_integrity([m])
+        v.process_validation_issues(issues)
         assert not mock_error.called
         assert mock_warn.called
 
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_silence_with_bad_input_and_check_warn(mock_warn, mock_error) -> None:
+def test_silence_with_bad_input_and_check_warn(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     m = Mod(foo=-10)
-    with pytest.raises(ValueError, match=('Input to silence should be a '
-                                          'warning object')):
-        v.silence('EXT:W')
-    v.check_integrity([m])
+    with pytest.raises(ValueError, match="Input to silence should be a warning object"):
+        v.silence(cast(Any, "EXT:W"))
+    issues = v.check_integrity([m])
+    v.process_validation_issues(issues)
     assert not mock_error.called
     assert mock_warn.called
 
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_silence_warning_already_in_silencers_is_ok(mock_warn, mock_error) -> None:
+def test_silence_warning_already_in_silencers_is_ok(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     from bokeh.core.validation.warnings import EXT
     m = Mod(foo=-10)
     try:
-        silencers0= v.silence(EXT)  # turn the warning off
+        silencers0 = v.silence(EXT)  # turn the warning off
         silencers1 = v.silence(EXT)  # do it a second time - no-op
         assert len(silencers0) == 1
         assert silencers0 == silencers1  # silencers is same as before
 
-        v.check_integrity([m])
+        issues = v.check_integrity([m])
+        v.process_validation_issues(issues)
         assert not mock_error.called
         assert not mock_warn.called
     finally:
         v.silence(EXT, False)  # turn the warning back on
-        v.check_integrity([m])
+        issues = v.check_integrity([m])
+        v.process_validation_issues(issues)
         assert not mock_error.called
         assert mock_warn.called
 
 @patch('bokeh.core.validation.check.log.error')
 @patch('bokeh.core.validation.check.log.warning')
-def test_silence_remove_warning_that_is_not_in_silencers_is_ok(mock_warn, mock_error) -> None:
+def test_silence_remove_warning_that_is_not_in_silencers_is_ok(mock_warn: MagicMock, mock_error: MagicMock) -> None:
     from bokeh.core.validation.warnings import EXT
     m = Mod(foo=-10)
 
@@ -183,9 +215,41 @@ def test_silence_remove_warning_that_is_not_in_silencers_is_ok(mock_warn, mock_e
     assert len(silencers1) == 0
     assert silencers1 == silencers2
 
-    v.check_integrity([m])
+    issues = v.check_integrity([m])
+    v.process_validation_issues(issues)
     assert not mock_error.called
     assert mock_warn.called
+
+@patch('bokeh.core.validation.check.log.error')
+@patch('bokeh.core.validation.check.log.warning')
+def test_process_validation_issues_pass(mock_warn: MagicMock, mock_error: MagicMock) -> None:
+    issues = ValidationIssues(error=[], warning=[])
+    v.process_validation_issues(issues)
+    assert not mock_error.called
+    assert not mock_warn.called
+
+@patch('bokeh.core.validation.check.log.error')
+@patch('bokeh.core.validation.check.log.warning')
+def test_process_validation_issues_warn(mock_warn: MagicMock, mock_error: MagicMock) -> None:
+    issues = ValidationIssues(
+        error=[ValidationIssue(9999, "EXT:E", "Custom extension reports error", "err")],
+        warning=[],
+    )
+    v.process_validation_issues(issues)
+    assert mock_error.called
+    assert not mock_warn.called
+
+@patch('bokeh.core.validation.check.log.error')
+@patch('bokeh.core.validation.check.log.warning')
+def test_process_validation_issues_error(mock_warn: MagicMock, mock_error: MagicMock) -> None:
+    issues = ValidationIssues(
+        error=[],
+        warning=[ValidationIssue(9999, "EXT:W", "Custom extension reports warning", "wrn")],
+    )
+    v.process_validation_issues(issues)
+    assert not mock_error.called
+    assert mock_warn.called
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
