@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,11 +8,18 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
+#-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
+# Standard library imports
+import asyncio
+from typing import List
+
 # Bokeh imports
 from bokeh.document.document import Document
 from bokeh.io import curdoc
@@ -31,7 +38,7 @@ import bokeh.document.locking as locking # isort:skip
 def test_next_tick_callback_works() -> None:
     d = locking.UnlockedDocumentProxy(Document())
     assert curdoc() is not d
-    curdoc_from_cb = []
+    curdoc_from_cb: List[Document] = []
     def cb():
         curdoc_from_cb.append(curdoc())
     callback_obj = d.add_next_tick_callback(cb)
@@ -53,7 +60,7 @@ def test_other_attrs_raise() -> None:
 def test_without_document_lock() -> None:
     d = Document()
     assert curdoc() is not d
-    curdoc_from_cb = []
+    curdoc_from_cb: List[Document] = []
     @locking.without_document_lock
     def cb():
         curdoc_from_cb.append(curdoc())
@@ -64,6 +71,23 @@ def test_without_document_lock() -> None:
     assert curdoc_from_cb[0]._doc is d
     assert isinstance(curdoc_from_cb[0], locking.UnlockedDocumentProxy)
 
+def test_without_document_lock_accepts_async_function() -> None:
+    i = 0
+    d = Document()
+
+    @locking.without_document_lock
+    async def cb():
+        nonlocal i
+        await asyncio.sleep(0.1)
+        i += 1
+    callback_obj = d.add_next_tick_callback(cb)
+
+    loop = asyncio.get_event_loop()
+    loop.run_until_complete(callback_obj.callback())
+
+    assert callback_obj.callback.nolock == True
+    assert i == 1
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
