@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -98,7 +100,7 @@ class Test_webdriver_control:
 
     @pytest.mark.selenium
     @pytest.mark.parametrize('kind', ['firefox', 'chromium'])
-    def test_create(self, kind) -> None:
+    def test_create(self, kind: biw.DriverKind) -> None:
         biw.webdriver_control.kind = kind
         assert biw.webdriver_control.kind == kind
         d = biw.webdriver_control.create()
