@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -21,8 +23,9 @@ import datetime as dt
 import mock
 
 # Bokeh imports
+from bokeh.core.validation import check_integrity, process_validation_issues
+
 from _util_models import check_properties_existence
-from bokeh.core.validation import check_integrity
 
 # Module under test
 from bokeh.models import Range1d, DataRange1d, FactorRange # isort:skip
@@ -228,17 +231,20 @@ class Test_FactorRange:
     def test_duplicate_factors_raises_validation_error(self) -> None:
         r = FactorRange("foo", "bar", "foo")
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([r])
+            issues = check_integrity([r])
+            process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
 
         r = FactorRange(factors=[("foo", "a"), ("foo", "b"),  ("foo", "a")])
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([r])
+            issues = check_integrity([r])
+            process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
 
         r = FactorRange(factors=[("foo", "a", "1"), ("foo", "a", "2"),  ("foo", "a", "1")])
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([r])
+            issues = check_integrity([r])
+            process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
 
 #-----------------------------------------------------------------------------
