@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,7 +17,6 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # External imports
-import networkx as nx
 import numpy as np
 from numpy.testing import assert_allclose
 
@@ -30,7 +31,7 @@ import bokeh.plotting.graph as bpg # isort:skip
 # General API
 #-----------------------------------------------------------------------------
 
-def test_from_networkx_method() -> None:
+def test_from_networkx_method(nx) -> None:
     G=nx.Graph()
     G.add_nodes_from([0,1,2,3])
     G.add_edges_from([[0,1], [0,2], [2,3]])
@@ -45,7 +46,7 @@ def test_from_networkx_method() -> None:
     assert_allclose(gl[0], np.array([1.0, 0.0]), atol=1e-7)
 
 
-def test_from_networkx_method_with_kwargs() -> None:
+def test_from_networkx_method_with_kwargs(nx) -> None:
     G=nx.Graph()
     G.add_nodes_from([0,1,2,3])
     G.add_edges_from([[0,1], [0,2], [2,3]])
@@ -57,7 +58,7 @@ def test_from_networkx_method_with_kwargs() -> None:
     assert_allclose(gl[0], np.array([2.0, 0.0]), atol=1e-7)
 
 
-def test_from_networkx_with_scalar_attributes() -> None:
+def test_from_networkx_with_scalar_attributes(nx) -> None:
     G = nx.Graph()
     G.add_nodes_from([(0, {"attr_1": "a", "attr_2": 10}),
                       (1, {"attr_1": "b"}),
@@ -77,7 +78,7 @@ def test_from_networkx_with_scalar_attributes() -> None:
     assert renderer.edge_renderer.data_source.data["attr_2"] == [None, 10]
 
 @pytest.mark.parametrize('typ', [list, tuple])
-def test_from_networkx_with_sequence_attributes(typ) -> None:
+def test_from_networkx_with_sequence_attributes(nx, typ) -> None:
     G = nx.Graph()
     G.add_nodes_from([(0, {"attr_1": typ([1, 2]), "attr_2": 10}),
                       (1, {}),
@@ -96,7 +97,7 @@ def test_from_networkx_with_sequence_attributes(typ) -> None:
     assert renderer.edge_renderer.data_source.data["attr_1"] == [[1, 11], [2, 22]]
     assert renderer.edge_renderer.data_source.data["attr_2"] == [None, 10]
 
-def test_from_networkx_errors_with_mixed_attributes() -> None:
+def test_from_networkx_errors_with_mixed_attributes(nx) -> None:
     G = nx.Graph()
     G.add_nodes_from([(0, {"attr_1": [1, 2], "attr_2": 10}),
                       (1, {}),
@@ -112,7 +113,7 @@ def test_from_networkx_errors_with_mixed_attributes() -> None:
     with pytest.raises(ValueError):
         bpg.from_networkx(G, nx.circular_layout)
 
-def test_from_networkx_with_bad_attributes() -> None:
+def test_from_networkx_with_bad_attributes(nx) -> None:
     G = nx.Graph()
     G.add_nodes_from([(0, {"index": "a", "attr_1": 10}),
                       (1, {"index": "b", "attr_1": 20})])
@@ -143,7 +144,7 @@ def test_from_networkx_with_bad_attributes() -> None:
         assert renderer.edge_renderer.data_source.data["end"] == [1]
         assert renderer.edge_renderer.data_source.data["attr_1"] == [10]
 
-def test_from_networkx_fixed_layout() -> None:
+def test_from_networkx_fixed_layout(nx) -> None:
     G = nx.Graph()
     G.add_nodes_from([0, 1, 2])
     G.add_edges_from([[0, 1], [0, 2]])
@@ -163,7 +164,7 @@ def test_from_networkx_fixed_layout() -> None:
     assert renderer.layout_provider.graph_layout[1] == fixed_layout[1]
     assert renderer.layout_provider.graph_layout[2] == fixed_layout[2]
 
-def test_from_networkx_with_missing_layout() -> None:
+def test_from_networkx_with_missing_layout(nx) -> None:
     G = nx.Graph()
     G.add_nodes_from([0, 1, 2])
     G.add_edges_from([[0, 1], [0, 2]])
