@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -25,7 +27,7 @@ import bokeh.protocol.message as message # isort:skip
 # General API
 #-----------------------------------------------------------------------------
 
-def test_create_header(monkeypatch) -> None:
+def test_create_header(monkeypatch: pytest.MonkeyPatch) -> None:
     message.Message.msgtype = "msgtype"
     monkeypatch.setattr("bokeh.util.serialization.make_id", lambda: "msgid")
     header = message.Message.create_header(request_id="bar")
