@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -16,6 +18,7 @@ import pytest ; pytest
 
 # Standard library imports
 import asyncio
+import gc
 
 # External imports
 from tornado.ioloop import IOLoop
@@ -34,21 +37,22 @@ import bokeh.server.contexts as bsc # isort:skip
 # General API
 #-----------------------------------------------------------------------------
 
-class TestBokehServerContext(object):
 
+class TestBokehServerContext:
     def test_init(self) -> None:
         ac = bsc.ApplicationContext("app", io_loop="ioloop")
         c = bsc.BokehServerContext(ac)
         assert c.application_context == ac
+        assert len(gc.get_referrers(ac)) == 0
 
     def test_sessions(self) -> None:
         ac = bsc.ApplicationContext("app", io_loop="ioloop")
         ac._sessions = dict(foo=1, bar=2)
         c = bsc.BokehServerContext(ac)
-        assert set(c.sessions) == set([1,2])
+        assert set(c.sessions) == {1, 2}
 
-class TestBokehSessionContext(object):
 
+class TestBokehSessionContext:
     def test_init(self) -> None:
         ac = bsc.ApplicationContext("app", io_loop="ioloop")
         sc = bsc.BokehServerContext(ac)
@@ -59,7 +63,7 @@ class TestBokehSessionContext(object):
         assert c.logout_url is None
 
     def test_destroyed(self) -> None:
-        class FakeSession(object):
+        class FakeSession:
             destroyed = False
         ac = bsc.ApplicationContext("app", io_loop="ioloop")
         sc = bsc.BokehServerContext(ac)
@@ -79,8 +83,8 @@ class TestBokehSessionContext(object):
         assert not c.destroyed
         assert c.logout_url == "/logout"
 
-class TestApplicationContext(object):
 
+class TestApplicationContext:
     def test_init(self) -> None:
         c = bsc.ApplicationContext("app", io_loop="ioloop")
         assert c.io_loop == "ioloop"
@@ -95,7 +99,7 @@ class TestApplicationContext(object):
     def test_sessions(self) -> None:
         c = bsc.ApplicationContext("app", io_loop="ioloop")
         c._sessions = dict(foo=1, bar=2)
-        assert set(c.sessions) == set([1,2])
+        assert set(c.sessions) == {1, 2}
 
     def test_get_session_success(self) -> None:
         c = bsc.ApplicationContext("app", io_loop="ioloop")
