@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -25,17 +27,24 @@ from datetime import timedelta
 
 # External imports
 import mock
+from _util_server import (
+    http_get,
+    url,
+    websocket_open,
+    ws_url,
+)
 from flaky import flaky
 from tornado.httpclient import HTTPError
 from tornado.httpserver import HTTPServer
-from tornado.ioloop import IOLoop, PeriodicCallback
+from tornado.ioloop import IOLoop
 
 # Bokeh imports
-from _util_server import http_get, url, websocket_open, ws_url
+from bokeh._testing.plugins.managed_server_loop import MSL
 from bokeh.application import Application
 from bokeh.application.handlers import Handler
 from bokeh.client import pull_session
 from bokeh.core.properties import List, String
+from bokeh.core.types import ID
 from bokeh.model import Model
 from bokeh.server.server import BaseServer, Server
 from bokeh.server.tornado import BokehTornado
@@ -63,37 +72,31 @@ class HookListModel(Model):
     hooks = List(String)
 
 class HookTestHandler(Handler):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.load_count = 0
         self.unload_count = 0
         self.session_creation_async_value = 0
         self.hooks = []
-        self.server_periodic_remover = None
-        self.session_periodic_remover = None
+        self.periodic_remover = None
 
     def modify_document(self, doc):
-        # this checks that the session created hook has run
-        # and session destroyed has not.
+        # checks that session created hook has run, and session destroyed has not.
         assert self.session_creation_async_value == 3
         doc.title = "Modified"
         doc.roots[0].hooks.append("modify")
         self.hooks.append("modify")
 
+        doc.add_next_tick_callback(self.on_next_tick)
+        doc.add_timeout_callback(self.on_timeout, 2)
+        periodic_cb = doc.add_periodic_callback(self.on_periodic, 3)
+        self.periodic_remover = lambda: doc.remove_periodic_callback(periodic_cb)
+
     def on_server_loaded(self, server_context):
         assert len(server_context.sessions) == 0
         self.load_count += 1
         self.hooks.append("server_loaded")
 
-        server_context.add_next_tick_callback(self.on_next_tick_server)
-        server_context.add_timeout_callback(self.on_timeout_server, 2)
-        periodic_cb_id = server_context.add_periodic_callback(self.on_periodic_server, 3)
-
-        def remover():
-            server_context.remove_periodic_callback(periodic_cb_id)
-
-        self.server_periodic_remover = remover
-
     def on_server_unloaded(self, server_context):
         self.unload_count += 1
         self.hooks.append("server_unloaded")
@@ -101,8 +104,7 @@ class HookTestHandler(Handler):
     # important to test that this can be async
     async def on_session_created(self, session_context):
         async def setup_document(doc):
-            # session creation hook is allowed to init the document
-            # before any modify_document() handlers kick in
+            # session creation hook is allowed to init the document before modify_document
             from bokeh.document import DEFAULT_TITLE
             hook_list = HookListModel()
             assert doc.title == DEFAULT_TITLE
@@ -116,16 +118,6 @@ class HookTestHandler(Handler):
 
         await session_context.with_locked_document(setup_document)
 
-        server_context = session_context.server_context
-        server_context.add_next_tick_callback(self.on_next_tick_session)
-        server_context.add_timeout_callback(self.on_timeout_session, 2)
-        periodic_cb_id = server_context.add_periodic_callback(self.on_periodic_session, 3)
-
-        def remover():
-            server_context.remove_periodic_callback(periodic_cb_id)
-
-        self.session_periodic_remover = remover
-
         self.hooks.append("session_created")
 
     # this has to be async too
@@ -140,31 +132,21 @@ class HookTestHandler(Handler):
 
         self.hooks.append("session_destroyed")
 
-    def on_next_tick_server(self):
-        self.hooks.append("next_tick_server")
+    def on_next_tick(self):
+        self.hooks.append("next_tick")
 
-    def on_timeout_server(self):
-        self.hooks.append("timeout_server")
+    def on_timeout(self):
+        self.hooks.append("timeout")
 
-    def on_periodic_server(self):
-        self.hooks.append("periodic_server")
-        self.server_periodic_remover()
-
-    def on_next_tick_session(self):
-        self.hooks.append("next_tick_session")
-
-    def on_timeout_session(self):
-        self.hooks.append("timeout_session")
-
-    def on_periodic_session(self):
-        self.hooks.append("periodic_session")
-        self.session_periodic_remover()
+    def on_periodic(self):
+        self.hooks.append("periodic")
+        self.periodic_remover()
 
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-def test_prefix(ManagedServerLoop) -> None:
+def test_prefix(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         assert server.prefix == ""
@@ -172,7 +154,7 @@ def test_prefix(ManagedServerLoop) -> None:
     with ManagedServerLoop(application, prefix="foo") as server:
         assert server.prefix == "/foo"
 
-def test_index(ManagedServerLoop) -> None:
+def test_index(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         assert server.index is None
@@ -180,7 +162,7 @@ def test_index(ManagedServerLoop) -> None:
     with ManagedServerLoop(application, index="foo") as server:
         assert server.index == "foo"
 
-async def test_get_sessions(ManagedServerLoop) -> None:
+async def test_get_sessions(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         server_sessions = server.get_sessions('/')
@@ -226,9 +208,6 @@ async def test_get_sessions(ManagedServerLoop) -> None:
         server_sessions = server.get_sessions()
         assert len(server_sessions) == 3
 
-# examples:
-# "sessionid" : "NzlNoPfEYJahnPljE34xI0a5RSTaU1Aq1Cx5"
-# 'sessionid':'NzlNoPfEYJahnPljE34xI0a5RSTaU1Aq1Cx5'
 token_in_json = re.compile("""["']token["'] *: *["']([^"]+)["']""")
 def extract_token_from_json(html):
     if not isinstance(html, str):
@@ -237,9 +216,6 @@ def extract_token_from_json(html):
     match = token_in_json.search(html)
     return match.group(1)
 
-# examples:
-# "sessionid" : "NzlNoPfEYJahnPljE34xI0a5RSTaU1Aq1Cx5"
-# 'sessionid':'NzlNoPfEYJahnPljE34xI0a5RSTaU1Aq1Cx5'
 use_for_title_in_json = re.compile("""["']use_for_title["'] *: *(false|true)""")
 def extract_use_for_title_from_json(html):
     if not isinstance(html, str):
@@ -264,12 +240,12 @@ def resource_files_requested(response, requested=True):
         else:
             assert file not in response
 
-def test_use_xheaders(ManagedServerLoop) -> None:
+def test_use_xheaders(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, use_xheaders=True) as server:
         assert server._http.xheaders == True
 
-def test_ssl_args_plumbing(ManagedServerLoop) -> None:
+def test_ssl_args_plumbing(ManagedServerLoop: MSL) -> None:
     with mock.patch.object(ssl, 'SSLContext'):
         with ManagedServerLoop({}, ssl_certfile="foo") as server:
             assert server._http.ssl_options.load_cert_chain.call_args[0] == ()
@@ -285,8 +261,6 @@ def test_ssl_args_plumbing(ManagedServerLoop) -> None:
             assert server._http.ssl_options.load_cert_chain.call_args[0] == ()
             assert server._http.ssl_options.load_cert_chain.call_args[1] == dict(certfile='foo', keyfile="baz", password="bar")
 
-# This test just maintains basic creation and setup, detailed functionality
-# is exercised by Server tests above
 def test_base_server() -> None:
     app = BokehTornado(Application())
     httpserver = HTTPServer(app)
@@ -305,7 +279,7 @@ def test_base_server() -> None:
     server.stop()
     server.io_loop.close()
 
-async def test_server_applications_callable_arg(ManagedServerLoop) -> None:
+async def test_server_applications_callable_arg(ManagedServerLoop: MSL) -> None:
     def modify_doc(doc):
         doc.title = "Hello, world!"
 
@@ -319,7 +293,7 @@ async def test_server_applications_callable_arg(ManagedServerLoop) -> None:
         session = server.get_sessions('/foo')[0]
         assert session.document.title == "Hello, world!"
 
-async def test__include_headers(ManagedServerLoop) -> None:
+async def test__include_headers(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, include_headers=['Custom']) as server:
         sessions = server.get_sessions('/')
@@ -332,7 +306,7 @@ async def test__include_headers(ManagedServerLoop) -> None:
         assert 'headers' in payload
         assert payload['headers'] == {'Custom': 'Test'}
 
-async def test__exclude_headers(ManagedServerLoop) -> None:
+async def test__exclude_headers(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, exclude_headers=['Connection', 'Host']) as server:
         sessions = server.get_sessions('/')
@@ -345,7 +319,7 @@ async def test__exclude_headers(ManagedServerLoop) -> None:
         assert 'headers' in payload
         assert payload["headers"].get("Accept-Encoding") == "gzip"
 
-async def test__include_cookies(ManagedServerLoop) -> None:
+async def test__include_cookies(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, include_cookies=['custom']) as server:
         sessions = server.get_sessions('/')
@@ -358,7 +332,7 @@ async def test__include_cookies(ManagedServerLoop) -> None:
         assert 'cookies' in payload
         assert payload['cookies'] == {'custom': 'test'}
 
-async def test__exclude_cookies(ManagedServerLoop) -> None:
+async def test__exclude_cookies(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, exclude_cookies=['custom']) as server:
         sessions = server.get_sessions('/')
@@ -382,23 +356,12 @@ async def test__exclude_cookies(ManagedServerLoop) -> None:
 @pytest.mark.skipif(sys.platform == "win32",
                     reason="Lifecycle hooks order different on Windows (TODO open issue)")
 @flaky(max_runs=10)
-def test__lifecycle_hooks(ManagedServerLoop) -> None:
+def test__lifecycle_hooks(ManagedServerLoop: MSL) -> None:
     application = Application()
     handler = HookTestHandler()
     application.add(handler)
     with ManagedServerLoop(application, check_unused_sessions_milliseconds=30) as server:
-        # wait for server callbacks to run before we mix in the
-        # session, this keeps the test deterministic
-        def check_done():
-            if len(handler.hooks) == 4:
-                server.io_loop.stop()
-        server_load_checker = PeriodicCallback(check_done, 1)
-        server_load_checker.start()
-        server.io_loop.start()
-        server_load_checker.stop()
-
-        # now we create a session
-        client_session = pull_session(session_id='test__lifecycle_hooks',
+        client_session = pull_session(session_id=ID("test__lifecycle_hooks"),
                                       url=url(server),
                                       io_loop=server.io_loop)
         client_doc = client_session.document
@@ -408,48 +371,43 @@ def test__lifecycle_hooks(ManagedServerLoop) -> None:
         server_doc = server_session.document
         assert len(server_doc.roots) == 1
 
-        # we have to capture these here for examination later, since after
-        # the session is closed, doc.roots will be emptied
-        client_hook_list = client_doc.roots[0]
-        server_hook_list = server_doc.roots[0]
+        # save for later, since doc.roots will be emptied after the session is closed
+        client_hook_list = list(client_doc.roots[0].hooks)
+        server_hook_list = list(server_doc.roots[0].hooks)
 
         client_session.close()
-        # expire the session quickly rather than after the
-        # usual timeout
+
+        # expire the session quickly rather than after the usual timeout
         server_session.request_expiration()
 
-        def on_done():
-            server.io_loop.stop()
-
-        server.io_loop.call_later(0.1, on_done)
+        server.io_loop.call_later(0.1, lambda: server.io_loop.stop())
 
         server.io_loop.start()
 
-    assert handler.hooks == ["server_loaded",
-                             "next_tick_server",
-                             "timeout_server",
-                             "periodic_server",
-                             "session_created",
-                             "modify",
-                             "next_tick_session",
-                             "timeout_session",
-                             "periodic_session",
-                             "session_destroyed",
-                             "server_unloaded"]
+    assert handler.hooks == [
+        "server_loaded",
+        "session_created",
+        "modify",
+        "next_tick",
+        "timeout",
+        "periodic",
+        "session_destroyed",
+        "server_unloaded",
+    ]
 
     assert handler.load_count == 1
     assert handler.unload_count == 1
-    # this is 3 instead of 6 because locked callbacks on destroyed sessions
-    # are turned into no-ops
+
+    # 3 instead of 6, because locked callbacks on destroyed sessions become no-ops
     assert handler.session_creation_async_value == 3
     assert client_doc.title == "Modified"
     assert server_doc.title == "Modified"
-    # only the handler sees the event that adds "session_destroyed" since
-    # the session is shut down at that point.
-    assert client_hook_list.hooks == ["session_created", "modify"]
-    assert server_hook_list.hooks == ["session_created", "modify"]
 
-async def test__request_in_session_context(ManagedServerLoop) -> None:
+    # only the handler sees "session_destroyed" since the session is shut down at that point.
+    assert client_hook_list == ["session_created", "modify"]
+    assert server_hook_list == ["session_created", "modify"]
+
+async def test__request_in_session_context(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         response = await http_get(server.io_loop, url(server) + "?foo=10")
@@ -463,7 +421,7 @@ async def test__request_in_session_context(ManagedServerLoop) -> None:
         # do we have a request
         assert session_context.request is not None
 
-async def test__request_in_session_context_has_arguments(ManagedServerLoop) -> None:
+async def test__request_in_session_context_has_arguments(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         response = await http_get(server.io_loop, url(server) + "?foo=10")
@@ -477,7 +435,7 @@ async def test__request_in_session_context_has_arguments(ManagedServerLoop) -> N
         # test if we can get the argument from the request
         assert session_context.request.arguments['foo'] == [b'10']
 
-async def test__no_request_arguments_in_session_context(ManagedServerLoop) -> None:
+async def test__no_request_arguments_in_session_context(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         response = await http_get(server.io_loop, url(server))
@@ -499,7 +457,7 @@ async def test__no_request_arguments_in_session_context(ManagedServerLoop) -> No
     ("&resources=none", False),
 ])
 
-async def test__resource_files_requested(querystring, requested, ManagedServerLoop) -> None:
+async def test__resource_files_requested(querystring, requested, ManagedServerLoop: MSL) -> None:
     """
     Checks if the loading of resource files is requested by the autoload.js
     response based on the value of the "resources" parameter.
@@ -509,7 +467,7 @@ async def test__resource_files_requested(querystring, requested, ManagedServerLo
         response = await http_get(server.io_loop, autoload_url(server) + querystring)
         resource_files_requested(response.body, requested=requested)
 
-async def test__autocreate_session_autoload(ManagedServerLoop) -> None:
+async def test__autocreate_session_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -524,7 +482,7 @@ async def test__autocreate_session_autoload(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert sessionid == sessions[0].id
 
-async def test__no_set_title_autoload(ManagedServerLoop) -> None:
+async def test__no_set_title_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -535,7 +493,7 @@ async def test__no_set_title_autoload(ManagedServerLoop) -> None:
         use_for_title = extract_use_for_title_from_json(js)
         assert use_for_title == "false"
 
-async def test__autocreate_session_doc(ManagedServerLoop) -> None:
+async def test__autocreate_session_doc(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -550,7 +508,7 @@ async def test__autocreate_session_doc(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert sessionid == sessions[0].id
 
-async def test__no_autocreate_session_websocket(ManagedServerLoop) -> None:
+async def test__no_autocreate_session_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -562,7 +520,7 @@ async def test__no_autocreate_session_websocket(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__use_provided_session_autoload(ManagedServerLoop) -> None:
+async def test__use_provided_session_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -579,7 +537,7 @@ async def test__use_provided_session_autoload(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert expected == sessions[0].id
 
-async def test__use_provided_session_header_autoload(ManagedServerLoop) -> None:
+async def test__use_provided_session_header_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -596,7 +554,7 @@ async def test__use_provided_session_header_autoload(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert expected == sessions[0].id
 
-async def test__use_provided_session_autoload_token(ManagedServerLoop) -> None:
+async def test__use_provided_session_autoload_token(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -615,7 +573,7 @@ async def test__use_provided_session_autoload_token(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert expected == sessions[0].id
 
-async def test__use_provided_session_doc(ManagedServerLoop) -> None:
+async def test__use_provided_session_doc(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -632,7 +590,7 @@ async def test__use_provided_session_doc(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert expected == sessions[0].id
 
-async def test__use_provided_session_websocket(ManagedServerLoop) -> None:
+async def test__use_provided_session_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -646,7 +604,7 @@ async def test__use_provided_session_websocket(ManagedServerLoop) -> None:
         assert 1 == len(sessions)
         assert expected == sessions[0].id
 
-async def test__autocreate_signed_session_autoload(ManagedServerLoop) -> None:
+async def test__autocreate_signed_session_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='foo') as server:
         sessions = server.get_sessions('/')
@@ -663,7 +621,7 @@ async def test__autocreate_signed_session_autoload(ManagedServerLoop) -> None:
 
         assert check_token_signature(token, signed=True, secret_key='foo')
 
-async def test__autocreate_signed_session_doc(ManagedServerLoop) -> None:
+async def test__autocreate_signed_session_doc(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='foo') as server:
         sessions = server.get_sessions('/')
@@ -681,9 +639,9 @@ async def test__autocreate_signed_session_doc(ManagedServerLoop) -> None:
         assert check_token_signature(token, signed=True, secret_key='foo')
 
 @flaky(max_runs=10)
-async def test__accept_session_websocket(ManagedServerLoop) -> None:
+async def test__accept_session_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
-    with ManagedServerLoop(application, session_token_expiration=1) as server:
+    with ManagedServerLoop(application, session_token_expiration=10) as server:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
@@ -696,7 +654,7 @@ async def test__accept_session_websocket(ManagedServerLoop) -> None:
         assert isinstance(msg, str)
         assert 'ACK' in msg
 
-async def test__reject_expired_session_websocket(ManagedServerLoop) -> None:
+async def test__reject_expired_session_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, session_token_expiration=1) as server:
         sessions = server.get_sessions('/')
@@ -711,7 +669,7 @@ async def test__reject_expired_session_websocket(ManagedServerLoop) -> None:
         ws = await websocket_open(server.io_loop, ws_url(server), subprotocols=["bokeh", token])
         assert await ws.read_queue.get() is None
 
-async def test__reject_wrong_subprotocol_websocket(ManagedServerLoop) -> None:
+async def test__reject_wrong_subprotocol_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -727,7 +685,7 @@ async def test__reject_wrong_subprotocol_websocket(ManagedServerLoop) -> None:
         ws = await websocket_open(server.io_loop, ws_url(server), subprotocols=["foo", token])
         assert await ws.read_queue.get() is None
 
-async def test__reject_no_token_websocket(ManagedServerLoop) -> None:
+async def test__reject_no_token_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         sessions = server.get_sessions('/')
@@ -741,7 +699,7 @@ async def test__reject_no_token_websocket(ManagedServerLoop) -> None:
         ws = await websocket_open(server.io_loop, ws_url(server), subprotocols=["foo"])
         assert await ws.read_queue.get() is None
 
-async def test__reject_unsigned_session_autoload(ManagedServerLoop) -> None:
+async def test__reject_unsigned_session_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='bar') as server:
         sessions = server.get_sessions('/')
@@ -755,7 +713,7 @@ async def test__reject_unsigned_session_autoload(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__reject_unsigned_token_autoload(ManagedServerLoop) -> None:
+async def test__reject_unsigned_token_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='bar') as server:
         sessions = server.get_sessions('/')
@@ -770,7 +728,7 @@ async def test__reject_unsigned_token_autoload(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__reject_unsigned_session_doc(ManagedServerLoop) -> None:
+async def test__reject_unsigned_session_doc(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='bar') as server:
         sessions = server.get_sessions('/')
@@ -784,7 +742,7 @@ async def test__reject_unsigned_session_doc(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__reject_unsigned_session_header_doc(ManagedServerLoop) -> None:
+async def test__reject_unsigned_session_header_doc(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='bar') as server:
         sessions = server.get_sessions('/')
@@ -798,7 +756,7 @@ async def test__reject_unsigned_session_header_doc(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__reject_unsigned_session_websocket(ManagedServerLoop) -> None:
+async def test__reject_unsigned_session_websocket(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, sign_sessions=True, secret_key='bar') as server:
         sessions = server.get_sessions('/')
@@ -811,7 +769,7 @@ async def test__reject_unsigned_session_websocket(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__no_generate_session_autoload(ManagedServerLoop) -> None:
+async def test__no_generate_session_autoload(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, generate_session_ids=False) as server:
         sessions = server.get_sessions('/')
@@ -824,7 +782,7 @@ async def test__no_generate_session_autoload(ManagedServerLoop) -> None:
         sessions = server.get_sessions('/')
         assert 0 == len(sessions)
 
-async def test__no_generate_session_doc(ManagedServerLoop) -> None:
+async def test__no_generate_session_doc(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, generate_session_ids=False) as server:
         sessions = server.get_sessions('/')
@@ -856,7 +814,7 @@ def test__existing_ioloop_with_multiple_processes_exception(ManagedServerLoop, e
         with ManagedServerLoop(application, io_loop=loop, num_procs=3):
             pass
 
-async def test__actual_port_number(ManagedServerLoop) -> None:
+async def test__actual_port_number(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application, port=0) as server:
         port = server.port
