@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -17,20 +19,25 @@ import pytest ; pytest
 # Standard library imports
 import json
 import logging
-import os
 import sys
 from subprocess import run
 
-# Bokeh imports
+# External imports
 from _util_server import http_get, url
+from tornado.web import StaticFileHandler
+
+# Bokeh imports
+from bokeh._testing.plugins.managed_server_loop import MSL
+from bokeh._testing.util.env import envset
 from bokeh.application import Application
 from bokeh.client import pull_session
+from bokeh.core.types import ID
 from bokeh.server.auth_provider import NullAuth
 from bokeh.server.views.static_handler import StaticHandler
 from bokeh.server.views.ws import WSHandler
 
 # Module under test
-import bokeh.server.tornado as tornado # isort:skip
+import bokeh.server.tornado as bst # isort:skip
 
 #-----------------------------------------------------------------------------
 # Setup
@@ -47,7 +54,7 @@ def test_windows_event_loop_fixup():
     proc = run([sys.executable, "-c", "import asyncio, sys; import bokeh.server.tornado; sys.exit(int(isinstance(asyncio.get_event_loop_policy(), asyncio.WindowsProactorEventLoopPolicy)))"'']) # noqa
     assert proc.returncode == 0, "bokeh.server did not fixup windows event loop"
 
-def test_default_resources(ManagedServerLoop) -> None:
+def test_default_resources(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         r = server._tornado.resources()
@@ -85,24 +92,22 @@ def test_default_resources(ManagedServerLoop) -> None:
         assert r.root_url == "/foo/bar/"
         assert r.path_versioner == StaticHandler.append_version
 
-def test_env_resources(ManagedServerLoop) -> None:
-    os.environ['BOKEH_RESOURCES'] = 'cdn'
-    application = Application()
-    with ManagedServerLoop(application) as server:
-        r = server._tornado.resources()
-        assert r.mode == "cdn"
-    del os.environ['BOKEH_RESOURCES']
+def test_env_resources(ManagedServerLoop: MSL) -> None:
+    with envset(BOKEH_RESOURCES="cdn"):
+        application = Application()
+        with ManagedServerLoop(application) as server:
+            r = server._tornado.resources()
+            assert r.mode == "cdn"
 
-def test_dev_resources(ManagedServerLoop) -> None:
-    os.environ['BOKEH_DEV'] = 'yes'
-    application = Application()
-    with ManagedServerLoop(application) as server:
-        r = server._tornado.resources()
-        assert r.mode == "absolute"
-        assert r.dev
-    del os.environ['BOKEH_DEV']
+def test_dev_resources(ManagedServerLoop: MSL) -> None:
+    with envset(BOKEH_DEV="yes"):
+        application = Application()
+        with ManagedServerLoop(application) as server:
+            r = server._tornado.resources()
+            assert r.mode == "absolute"
+            assert r.dev
 
-def test_index(ManagedServerLoop) -> None:
+def test_index(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         assert server._tornado.index is None
@@ -110,7 +115,7 @@ def test_index(ManagedServerLoop) -> None:
     with ManagedServerLoop(application, index='foo') as server:
         assert server._tornado.index == "foo"
 
-def test_prefix(ManagedServerLoop) -> None:
+def test_prefix(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         assert server._tornado.prefix == ""
@@ -120,30 +125,30 @@ def test_prefix(ManagedServerLoop) -> None:
             assert server._tornado.prefix == "/foo"
 
 def test_xsrf_cookies() -> None:
-    bt = tornado.BokehTornado(applications={})
+    bt = bst.BokehTornado(applications={})
     assert not bt.settings['xsrf_cookies']
 
-    bt = tornado.BokehTornado(applications={}, xsrf_cookies=True)
+    bt = bst.BokehTornado(applications={}, xsrf_cookies=True)
     assert bt.settings['xsrf_cookies']
 
 def test_auth_provider() -> None:
-    bt = tornado.BokehTornado(applications={})
+    bt = bst.BokehTornado(applications={})
     assert isinstance(bt.auth_provider, NullAuth)
 
     class FakeAuth:
         get_user = "get_user"
         endpoints = []
-    bt = tornado.BokehTornado(applications={}, auth_provider=FakeAuth)
+    bt = bst.BokehTornado(applications={}, auth_provider=FakeAuth)
     assert bt.auth_provider is FakeAuth
 
 def test_websocket_max_message_size_bytes() -> None:
     app = Application()
-    t = tornado.BokehTornado({"/": app}, websocket_max_message_size_bytes=12345)
+    t = bst.BokehTornado({"/": app}, websocket_max_message_size_bytes=12345)
     assert t.settings['websocket_max_message_size'] == 12345
 
 def test_websocket_compression_level() -> None:
     app = Application()
-    t = tornado.BokehTornado({"/": app}, websocket_compression_level=2,
+    t = bst.BokehTornado({"/": app}, websocket_compression_level=2,
                              websocket_compression_mem_level=3)
     ws_rules = [rule for rule in t.wildcard_router.rules if issubclass(rule.target, WSHandler)]
     assert len(ws_rules) == 1
@@ -170,26 +175,26 @@ def test_websocket_origins(ManagedServerLoop, unused_tcp_port) -> None:
 
 def test_default_app_paths() -> None:
     app = Application()
-    t = tornado.BokehTornado({}, "", [])
+    t = bst.BokehTornado({}, "", [])
     assert t.app_paths == set()
 
-    t = tornado.BokehTornado({"/": app}, "", [])
+    t = bst.BokehTornado({"/": app}, "", [])
     assert t.app_paths == { "/" }
 
-    t = tornado.BokehTornado({"/": app, "/foo": app}, "", [])
+    t = bst.BokehTornado({"/": app, "/foo": app}, "", [])
     assert t.app_paths == { "/", "/foo"}
 
 # tried to use capsys to test what's actually logged and it wasn't
 # working, in the meantime at least this tests that log_stats
 # doesn't crash in various scenarios
-def test_log_stats(ManagedServerLoop) -> None:
+def test_log_stats(ManagedServerLoop: MSL) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
         server._tornado._log_stats()
-        session1 = pull_session(session_id='session1',
+        session1 = pull_session(session_id=ID("session1"),
                                 url=url(server),
                                 io_loop=server.io_loop)
-        session2 = pull_session(session_id='session2',
+        session2 = pull_session(session_id=ID("session2"),
                                 url=url(server),
                                 io_loop=server.io_loop)
         server._tornado._log_stats()
@@ -197,7 +202,7 @@ def test_log_stats(ManagedServerLoop) -> None:
         session2.close()
         server._tornado._log_stats()
 
-async def test_metadata(ManagedServerLoop) -> None:
+async def test_metadata(ManagedServerLoop: MSL) -> None:
     application = Application(metadata=dict(hi="hi", there="there"))
     with ManagedServerLoop(application) as server:
         meta_url = url(server) + 'metadata'
@@ -220,6 +225,40 @@ async def test_metadata(ManagedServerLoop) -> None:
 # Dev API
 #-----------------------------------------------------------------------------
 
+class Test_create_static_handler:
+
+    def test_app_static_path(self):
+        app = Application()
+        app._static_path = "foo"
+
+        result = bst.create_static_handler("/prefix", "/key", app)
+        assert len(result) == 3
+        assert result[0] == "/prefix/key/static/(.*)"
+        assert result[1] == StaticFileHandler
+        assert result[2] == {"path" : app.static_path}
+
+        result = bst.create_static_handler("/prefix", "/", app)
+        assert len(result) == 3
+        assert result[0] == "/prefix/static/(.*)"
+        assert result[1] == StaticFileHandler
+        assert result[2] == {"path" : app.static_path}
+
+    def test_no_app_static_path(self):
+        app = Application()
+        app._static_path = None
+
+        result = bst.create_static_handler("/prefix", "/key", app)
+        assert len(result) == 3
+        assert result[0] == "/prefix/key/static/(.*)"
+        assert result[1] == StaticHandler
+        assert result[2] == {}
+
+        result = bst.create_static_handler("/prefix", "/", app)
+        assert len(result) == 3
+        assert result[0] == "/prefix/static/(.*)"
+        assert result[1] == StaticHandler
+        assert result[2] == {}
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
