@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -19,6 +21,7 @@ import warnings
 
 # Bokeh imports
 from bokeh._testing.util.api import verify_all
+from bokeh._testing.util.types import Capture
 from bokeh.util.warnings import BokehDeprecationWarning, BokehUserWarning
 
 # Module under test
@@ -35,7 +38,7 @@ ALL =  (
 )
 
 _LICENSE = """\
-Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors
+Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -78,7 +81,7 @@ def test___version___type() -> None:
 def test___version___defined() -> None:
     assert b.__version__ != 'unknown'
 
-def test_license(capsys) -> None:
+def test_license(capsys: Capture) -> None:
     b.license()
     out, err = capsys.readouterr()
     assert out == _LICENSE
