@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,7 +17,7 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # External imports
-from mock import patch
+from mock import MagicMock, patch
 
 # Bokeh imports
 from bokeh._testing.util.api import verify_all
@@ -38,7 +40,7 @@ ALL =  (
 Test___all__ = verify_all(bm, ALL)
 
 @patch('bokeh.command.bootstrap.main')
-def test_main(mock_main) -> None:
+def test_main(mock_main: MagicMock) -> None:
     import sys
     old_argv = sys.argv
     sys.argv = ["foo", "bar"]
