@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -32,7 +34,7 @@ point_events = {v for v in globals().values() if isinstance(v, type) and issubcl
 #-----------------------------------------------------------------------------
 
 class EventCallback:
-    def __init__(self, attributes=[]):
+    def __init__(self, attributes=[]) -> None:
         self.event_name = None
         self.attributes = attributes
         self.payload = {}
