@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -16,10 +18,10 @@ import pytest ; pytest
 
 # Standard library imports
 import logging
-import os
 
 # Bokeh imports
 from bokeh._testing.util.api import verify_all
+from bokeh._testing.util.env import envset
 
 # Module under test
 import bokeh.settings as bs # isort:skip
@@ -46,6 +48,7 @@ _expected_settings = (
     'browser',
     'cdn_version',
     'cookie_secret',
+    'docs_alert',
     'docs_cdn',
     'docs_version',
     'ignore_filename',
@@ -64,7 +67,7 @@ _expected_settings = (
     'ssl_certfile',
     'ssl_keyfile',
     'ssl_password',
-    'strict',
+    'validation_level',
     'xsrf_cookies',
 )
 
@@ -89,11 +92,12 @@ class TestSettings:
         assert bs.settings.minified.convert_type == "Bool"
         assert bs.settings.perform_document_validation.convert_type == "Bool"
         assert bs.settings.simple_ids.convert_type == "Bool"
-        assert bs.settings.strict.convert_type == "Bool"
         assert bs.settings.xsrf_cookies.convert_type == "Bool"
 
         assert bs.settings.py_log_level.convert_type == "Log Level"
 
+        assert bs.settings.validation_level.convert_type == "Validation Level"
+
         assert bs.settings.allowed_ws_origin.convert_type == "List[String]"
 
         default_typed = set(_expected_settings) - {
@@ -102,7 +106,7 @@ class TestSettings:
             'minified',
             'perform_document_validation',
             'simple_ids',
-            'strict',
+            'validation_level',
             'py_log_level',
             'allowed_ws_origin',
             'xsrf_cookies',
@@ -157,6 +161,14 @@ class TestConverters:
         with pytest.raises(ValueError):
             bs.convert_logging("junk")
 
+    @pytest.mark.parametrize("value", ["none", "errors", "all"])
+    def test_convert_validation_good(self, value) -> None:
+        assert bs.convert_validation(value) == value
+
+    def test_convert_validation_bad(self) -> None:
+        with pytest.raises(ValueError):
+            bs.convert_validation("junk")
+
 class TestPrioritizedSetting:
     def test_env_var_property(self) -> None:
         ps = bs.PrioritizedSetting("foo", env_var="BOKEH_FOO")
@@ -196,24 +208,21 @@ class TestPrioritizedSetting:
     def test_dev_default(self) -> None:
         ps = bs.PrioritizedSetting("foo", env_var="BOKEH_FOO", default=10, dev_default=25)
         assert ps.dev_default == 25
-        os.environ['BOKEH_DEV'] = "yes"
-        assert ps() == 25
-        assert ps(default=20) == 25
-        del os.environ['BOKEH_DEV']
+        with envset(BOKEH_DEV="yes"):
+            assert ps() == 25
+            assert ps(default=20) == 25
 
     def test_env_var(self) -> None:
-        os.environ["BOKEH_FOO"] = "30"
-        ps = bs.PrioritizedSetting("foo", env_var="BOKEH_FOO")
-        assert ps.env_var == "BOKEH_FOO"
-        assert ps() == "30"
-        assert ps(default=20) == "30"
-        del os.environ["BOKEH_FOO"]
+        with envset(BOKEH_FOO="30"):
+            ps = bs.PrioritizedSetting("foo", env_var="BOKEH_FOO")
+            assert ps.env_var == "BOKEH_FOO"
+            assert ps() == "30"
+            assert ps(default=20) == "30"
 
     def test_env_var_converts(self) -> None:
-        os.environ["BOKEH_FOO"] = "30"
-        ps = bs.PrioritizedSetting("foo", convert=int, env_var="BOKEH_FOO")
-        assert ps() == 30
-        del os.environ["BOKEH_FOO"]
+        with envset(BOKEH_FOO="30"):
+            ps = bs.PrioritizedSetting("foo", convert=int, env_var="BOKEH_FOO")
+            assert ps() == 30
 
     def test_user_set(self) -> None:
         ps = bs.PrioritizedSetting("foo")
@@ -258,9 +267,8 @@ class TestPrioritizedSetting:
         assert ps(default=10) == 10
 
         # 1.5. implicit default (DEV)
-        os.environ['BOKEH_DEV'] = "yes"
-        assert ps() == 15
-        del os.environ['BOKEH_DEV']
+        with envset(BOKEH_DEV="yes"):
+            assert ps() == 15
 
         # 2. global config file
         FakeSettings.config_system['foo'] = 20
@@ -273,25 +281,23 @@ class TestPrioritizedSetting:
         assert ps(default=10) == 30
 
         # 4. environment variable
-        os.environ["BOKEH_FOO"] = "40"
-        assert ps() == 40
-        assert ps(default=10) == 40
+        with envset(BOKEH_FOO="40"):
+            assert ps() == 40
+            assert ps(default=10) == 40
 
-        # 5. override config file
-        FakeSettings.config_override['foo'] = 50
-        assert ps() == 50
-        assert ps(default=10) == 50
+            # 5. override config file
+            FakeSettings.config_override['foo'] = 50
+            assert ps() == 50
+            assert ps(default=10) == 50
 
-        # 6. previously user-set value
-        ps.set_value(60)
-        assert ps() == 60
-        assert ps(default=10) == 60
+            # 6. previously user-set value
+            ps.set_value(60)
+            assert ps() == 60
+            assert ps(default=10) == 60
 
-        # 7. immediate values
-        assert ps(70) == 70
-        assert ps(70, default=10) == 70
-
-        del os.environ["BOKEH_FOO"]
+            # 7. immediate values
+            assert ps(70) == 70
+            assert ps(70, default=10) == 70
 
     def test_descriptors(self) -> None:
         class FakeSettings:
