@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -45,21 +47,21 @@ class ThemedModel(Model):
 class SubOfThemedModel(ThemedModel):
     another_string = String("world")
 
-FILE_CONTENTS = """
+FILE_CONTENTS = b"""
 attrs:
     ThemedModel:
         number: 57
     SubOfThemedModel:
         another_string: "boo"
-""".encode('utf-8')
+"""
 
-class TestThemes(object):
 
+class TestThemes:
     def test_construct_empty_theme_from_file(self) -> None:
         # windows will throw permissions error with auto-delete
         with (tempfile.NamedTemporaryFile(delete=False)) as file:
             # create and apply empty theme with no exception thrown
-            file.file.write("".encode('utf-8'))
+            file.file.write(b"")
             file.file.flush()
             theme = Theme(filename=file.name)
             theme.apply_to_model(ThemedModel())
