@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -15,7 +17,7 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # External imports
-from mock import patch
+from mock import MagicMock, patch
 
 # Module under test
 import bokeh.util.deprecation as dep # isort:skip
@@ -30,13 +32,8 @@ def foo(): pass
 # General API
 #-----------------------------------------------------------------------------
 
-def test_bad_arg_type() -> None:
-    for x in [10, True, foo, [], (), {}]:
-        with pytest.raises(ValueError):
-            dep.deprecated(x)
-
 @patch('warnings.warn')
-def test_message(mock_warn) -> None:
+def test_message(mock_warn: MagicMock) -> None:
     dep.deprecated('test')
     assert mock_warn.called
     assert mock_warn.call_args[0] == ("test", dep.BokehDeprecationWarning)
@@ -73,14 +70,14 @@ def test_since_bad_tuple() -> None:
         dep.deprecated((1,2,"3"), old="foo", new="bar")
 
 @patch('warnings.warn')
-def test_since(mock_warn) -> None:
+def test_since(mock_warn: MagicMock) -> None:
     dep.deprecated((1,2,3), old="foo", new="bar")
     assert mock_warn.called
     assert mock_warn.call_args[0] == ("foo was deprecated in Bokeh 1.2.3 and will be removed, use bar instead.", dep.BokehDeprecationWarning)
     assert mock_warn.call_args[1] == {'stacklevel': 2}
 
 @patch('warnings.warn')
-def test_since_with_extra(mock_warn) -> None:
+def test_since_with_extra(mock_warn: MagicMock) -> None:
     dep.deprecated((1,2,3), old="foo", new="bar", extra="baz")
     assert mock_warn.called
     assert mock_warn.call_args[0] == ("foo was deprecated in Bokeh 1.2.3 and will be removed, use bar instead. baz", dep.BokehDeprecationWarning)
